<?php

namespace App\Http\Controllers\Admin;

use App\Models\User;
use App\Constants\Status;
use App\Models\Promotion;
use Illuminate\Http\Request;
use App\Models\CreditHistory;
use App\Http\Controllers\Controller;

class AdvertisementController extends Controller
{

    public function adAll()
    {
        $pageTitle = 'All Advertisement';
        $ads = Promotion::latest()->paginate(getPaginate());
        return view('admin.ad.allAd', compact('pageTitle',  'ads'));
    }

    public function pending()
    {
        $pageTitle = 'Pending Advertisement';
        $ads = Promotion::whereIn('status', [Status::CREATED, Status::EDITED])->latest()->paginate(getPaginate());
        return view('admin.ad.pending', compact('pageTitle',  'ads'));
    }

    public function adAdmin()
    {
        $pageTitle = "Admin's Advertisement";
        $ads = Promotion::where('user_id', 0)->latest()->paginate(getPaginate());
        return view('admin.ad.admin', compact('pageTitle',  'ads'));
    }

    public function adUser()
    {
        $pageTitle = "User's Advertisement";
        $ads = Promotion::where('user_id', '!=', 0)->latest()->paginate(getPaginate());
        return view('admin.ad.users', compact('pageTitle',  'ads'));
    }

    public function adCreate(Request $request)
    {
        $request->validate([
            'url'    => 'required|url',
            'click'  => 'required|integer|gt:0',
            'credit' => 'required|numeric|gt:0',
            'title'  => 'required|max:191',
            'image'  => 'required|mimes:png,jpg,jpeg',
        ]);

        $promotion = new Promotion();
        $promotion->status = 1;
        $promotion->title = $request->title;
        $promotion->user_id = 0;
        $promotion->url = $request->url;
        $promotion->click = $request->click;
        $promotion->credit = $request->credit;
        $promotion->publication_status = $request->publication_status ? Status::PUBLISHED : Status::UNPUBLISHED;

        if ($request->hasFile('image')) {
            try {
                $promotion->image = fileUploader($request->image, getFilePath('advertisement'), getFileSize('advertisement'));
            } catch (\Exception $exp) {
                $notify[] = ['errors', 'Image could not be uploaded.'];
                return back()->withNotify($notify);
            }
        }

        $promotion->save();

        $notify[] = ['success', 'Advertisement added successfully'];
        return redirect()->back()->withNotify($notify);
    }

    public function adEdit(Request $request)
    {

        $request->validate([
            'id' => 'required|exists:promotions,id',
            'url' => 'required|url',
            'title' => 'required|max:191',
            'image' => 'mimes:png,jpg,jpeg',
        ]);

        $findAd = Promotion::where('id', $request->id)->where('user_id', 0)->firstOrFail();
        $findAd->title = $request->title;
        $findAd->url = $request->url;
        $findAd->publication_status = $request->publication_status ? Status::PUBLISHED : Status::UNPUBLISHED;

        if ($request->hasFile('image')) {
            try {
                $findAd->image = fileUploader($request->image, getFilePath('advertisement'), getFileSize('advertisement'), $findAd->image);
            } catch (\Exception $exp) {
                $notify[] = ['errors', 'Image could not be uploaded.'];
                return back()->withNotify($notify);
            }
        }
        $findAd->save();

        $notify[] = ['success', 'Advertisement updated successfully'];
        return back()->withNotify($notify);
    }

    public function delete($id)
    {
        $promotion = Promotion::findOrFail($id);
        fileManager()->removeFile(getFilePath('advertisement') . '/' . $promotion->image);
        $promotion->delete();

        $notify[] = ['success', 'Advertisement deleted successfully'];
        return back()->withNotify($notify);
    }

    public function approve($id)
    {
        $ad = Promotion::whereIn('status', [Status::CREATED, Status::EDITED])->findOrFail($id);
        if ($ad->click <= $ad->clicked) {
            $ad->status = Status::RUNNING;
        } else {
            $ad->status = 1;
            $user = User::findOrFail($ad->user_id);

            notify($user, 'AD_APPROVED', [
                'title' => $ad->title,
                'url' => $ad->url,
                'expected_click' => $ad->click,
                'total_credit' => $ad->total_credit,
                'per_click_credit' => getAmount($ad->credit),
                'duration' => getAmount($ad->duration),
                'clicked' => $ad->clicked,
                'status' => 'Running',
            ]);
        }

        $ad->save();

        $notify[] = ['success', 'Advertisement approved successfully'];
        return back()->withNotify($notify);
    }

    public function reject($id)
    {
        $ad = Promotion::whereIn('status', [Status::CREATED, Status::EDITED])->findOrFail($id);

        if ($ad->clicked == 0) {
            $user = User::findOrFail($ad->user_id);
            $user->credit += $ad->total_credit;
            $user->save();

            $creditHistory = new CreditHistory();
            $creditHistory->user_id = $user->id;
            $creditHistory->type = ' + ';
            $creditHistory->price = 0;
            $creditHistory->credit = $ad->total_credit;
            $creditHistory->credit_post_balance = $user->credit;
            $creditHistory->details = 'Your requested advertisement has been rejected';
            $creditHistory->save();

            notify($user, 'AD_REJECT', [
                'title' => $ad->title,
                'url' => $ad->url,
                'expected_click' => $ad->click,
                'per_click_credit' => getAmount($ad->credit),
                'duration' => getAmount($ad->duration),
                'clicked' => $ad->clicked,
                'status' => 'Rejected',
                'return_credit' => $ad->total_credit,
            ]);

            $ad->status = Status::REJECTED;
        } else {
            $ad->status = Status::REJECTED;
        }

        $ad->save();

        $notify[] = ['success', 'Advertisement rejected successfully'];
        return back()->withNotify($notify);
    }

    public function topView()
    {
        $pageTitle = 'Top View Advertisement';
        $ads = Promotion::orderBy('clicked', 'DESC')->where('clicked', '>', 0)->paginate(getPaginate());
        return view('admin.ad.allAd', compact('pageTitle', 'ads'));
    }
}
