@extends('admin.layouts.app')

@section('panel')
    <div class="row">

        <div class="col-lg-12">
            <div class="card b-radius--10 ">
                <div class="card-body p-0">
                    <div class="table-responsive--sm table-responsive">
                        <table class="table table--light style--two">

                            <thead>
                                <tr>
                                    <th>@lang('Title')</th>
                                    <th>@lang('Url')</th>
                                    <th>@lang('Status')</th>
                                    <th>@lang('Clicked')</th>
                                    <th>@lang('Publication Status') </th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($promotions as $data)
                                    <tr>
                                        <td>
                                            {{ strLimit(__($data->title), 40) }}
                                        </td>

                                        <td>
                                            {{ strLimit($data->url, 40) }}
                                        </td>

                                        <td>
                                            @if ($data->status == 1)
                                                <span class="badge badge--primary">@lang('Running')</span>
                                            @else
                                                <span class="badge badge--success">@lang('Completed')</span>
                                            @endif
                                        </td>

                                        <td>
                                            {{ $data->clicked }}
                                        </td>

                                        <td>
                                            @if ($data->publication_status == 1)
                                                <span class="badge badge--success">@lang('Published')</span>
                                            @else
                                                <span class="badge badge--danger">@lang('Unublished')</span>
                                            @endif
                                        </td>

                                        <td>
                                            <div class="button--group">
                                                <button type="button" class="btn btn-sm btn-outline--primary viewBtn" data-title="{{ $data->title }}" data-click="{{ getAmount($data->click) }}" data-credit="{{ getAmount($data->credit) }}" data-clicked="{{ getAmount($data->clicked) }}" data-type="{{ $data->type }}" data-url="{{ $data->url }}" data-publish="{{ $data->publication_status }}" data-image="{{ getImage(getFilePath('advertisement') . '/' . $data->image, getFileSize('advertisement')) }}"><i class="las la-eye"></i> @lang('View')</button>

                                                <button type="button" class="btn btn-sm btn-outline--danger confirmationBtn" data-action="{{ route('admin.ad.delete', $data->id) }}" data-question="@lang('Are you sure to delete this advertisement?')">
                                                    <i class="las la-trash-alt"></i>@lang('Delete')
                                                </button>
                                            </div>
                                        </td>
                                    @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse

                            </tbody>
                        </table><!-- table end -->
                    </div>
                </div>
                @if ($promotions->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($promotions) }}
                    </div>
                @endif
            </div><!-- card end -->
        </div>
    </div>

    <div id="viewModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('View details')</h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <div class="modal-body">
                    <div class="row">
                        <div class="col-lg-12 form-group">
                            <label for="title">@lang('Title')</label>
                            <input type="text" value="{{ old('title') }}" readonly name="title" class="form-control" required>
                        </div>
                        <div class="col-lg-12 form-group">
                            <label for="url">@lang('Url')</label>
                            <input type="url" value="{{ old('url') }}" readonly name="url" class="form-control" required>
                        </div>
                        <div class="col-lg-6 form-group">
                            <label for="status">@lang('Publication Status')</label>
                            <input type="text" name="status" readonly="" class="form-control" required>
                        </div>
                        <div class="col-lg-6 form-group">
                            <label for="type">@lang('Video Type')</label>
                            <input type="text" name="type" class="form-control" readonly="">
                        </div>
                        <div class="col-lg-4 form-group">
                            <label for="click">@lang('Expected Click')</label>
                            <input type="number" name="click" value="{{ old('click') }}" readonly class="form-control" min='1' required>
                        </div>
                        <div class="col-lg-4 form-group">
                            <label for="credit">@lang('Per click Credit')</label>
                            <input type="number" name="credit" value="{{ old('credit') }}" readonly class="form-control" min='1' required>
                        </div>
                        <div class="col-lg-4 form-group">
                            <label for="duration">@lang('Duration - seconds')</label>
                            <input type="number" name="duration" value="{{ old('duration') }}" readonly class="form-control" min='1' required>
                        </div>
                        <div class="col-lg-12">
                            <div class="image-upload">
                                <div class="thumb">
                                    <x-image-uploader id="new" class="w-100" type="advertisement" :required=false />
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn--dark" data-bs-dismiss="modal">@lang('Close')</button>
                </div>
            </div>
        </div>
    </div>

    <x-confirmation-modal />
@endsection

@push('script')
    <script>
        (function($) {
            "use strict";

            $('.viewBtn').on('click', function() {
                var modal = $('#viewModal');
                modal.find('input[name=title]').val($(this).data('title'));
                modal.find('input[name=url]').val($(this).data('url'));
                modal.find('input[name=click]').val($(this).data('click'));
                modal.find('input[name=credit]').val($(this).data('credit'));
                modal.find('input[name=clicked]').val($(this).data('clicked'));
                modal.find('input[name=duration]').val($(this).data('duration'));
                modal.find('input[name=type]').val($(this).data('type') == 1 ? 'Video' : 'Not Video');
                modal.find('input[name=status]').val($(this).data('publish') == 1 ? 'Published' : 'Unpublished');
                // modal.find('.profilePicPreview').attr("style", "background-image:url(" + $(this).data('image') + ")");
                $('.image-upload-preview').css({
                    "background-image": "url(" + $(this).data('image') + ")"
                });
                modal.find('.image-upload-input-wrapper').css({
                    "display": "none"
                });
                modal.modal('show');
            });

        })(jQuery);
    </script>
@endpush

@push('style')
    <style>
        input::-webkit-outer-spin-button,
        input::-webkit-inner-spin-button {
            -webkit-appearance: none;
            margin: 0;
        }

        input[type=number] {
            -moz-appearance: textfield;
        }
    </style>
@endpush
