@extends('Template::layouts.master')
@section('content')
    <section class="dashboard-section pt-80">
        <div class="container">
            <div class="pb-80 text-center">
                <h5 class="title mb-3"></h5>
                <table class="table cmn--table">
                    <thead>
                        <tr>
                            <th>@lang('Title')</th>
                            <th>@lang('Expected Click')</th>
                            <th>@lang('Per Click Credit')</th>
                            <th>@lang('Clicked')</th>
                            <th>@lang('Status')</th>
                            <th>@lang('Publication Status')</th>
                            <th>@lang('Action')</th>
                        </tr>
                    </thead>
                    <tbody>
                        @forelse($logs as $k=>$data)
                            <tr>
                                <td>{{ strLimit($data->title, 15) }}</td>
                                <td>{{ getAmount($data->click) }}</td>
                                <td>{{ getAmount($data->credit) }}</td>
                                <td>{{ $data->clicked }}</td>
                                <td>
                                    @php
                                        echo $data->statusBadge;
                                    @endphp
                                </td>
                                <td>
                                    @if ($data->publication_status == Status::PUBLISHED)
                                        <span class="badge rounded-pill bg-success">@lang('Published')</span>
                                    @else
                                        <span class="badge rounded-pill bg-warning">@lang('Unpublished')</span>
                                    @endif
                                </td>
                                <td>
                                    <div class="button--group">
                                        @if ($data->status != 5)
                                            <a href="javascript:void(0)" data-id="{{ $data->id }}" data-url="{{ $data->url }}" data-title="{{ $data->title }}" data-duration="{{ getAmount($data->duration) }}" data-publish="{{ $data->publication_status }}" data-type="{{ $data->type }}" data-image="{{ getImage(getFilePath('advertisement') . '/' . $data->image, getFileSize('advertisement')) }}" class="icon-btn editBtn text--base"><i class="las la-edit"></i> @lang('Edit')</a>
                                        @endif
                                        <a href="javascript:void(0)" data-id="{{ $data->id }}" class="icon-btn text--danger deleteBtn">
                                            <i class="las la-trash-alt"></i> @lang('Delete')
                                        </a>
                                    </div>
                                </td>
                            </tr>
                        @empty
                            <tr>
                                <td colspan="100%" class="justify-content-center custom--label text--title"> @lang('There is no data')</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>
                {{ paginateLinks($logs, 'Template::paginate') }}
            </div>

        </div>
    </section>

    {{-- EDIT MODAL --}}
    <div id="editModal" class="modal modal-lg fade" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Details')</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>

                <form action="{{ route('user.promotion.edit') }}" method="post" enctype="multipart/form-data" class="editForm">
                    @csrf
                    <div class="modal-body">
                        <div class="row">
                            <input type="hidden" name="id">
                            <div class="col-lg-6">
                                <div class="image-upload">
                                    <div class="thumb">
                                        <div class="avatar-preview">
                                            <div class="row">
                                                <div class="col-sm-12">
                                                    <div class="profilePicPreview" id="display_image">
                                                        <span class="size_mention"></span>
                                                        <button type="button" id="image_remove_id" class="remove-image"><i class="fa fa-times"></i></button>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="avatar-edit">
                                            <input type="file" class="profilePicUpload" id="profilePicUpload1" accept=".png, .jpg, .jpeg" name="image">
                                            <label for="profilePicUpload1" id='image_btn' class="btn btn-primary">@lang('Select Image') </label>
                                            <span class="custom--label text--title">
                                                @lang('Supported image .jpeg, .png, .jpg, 300x250')
                                            </span>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="col-lg-6">
                                <div class="form--group">
                                    <label for="title" class="custom--label text--title">@lang('Title')*</label>
                                    <input type="title" id="title" required name="title" class="form-control form--control">
                                </div>
                                <div class="form--group">
                                    <label for="url" class="custom--label text--title">@lang('Url')* <code class="videoLinkExample"></code></label>
                                    <input type="url" id="url" required name="url" class="form-control form--control">
                                </div>
                                <div class="form--group">
                                    <label for="publication_status" class="custom--label text--title">@lang('Publication Status')*</label>
                                    <select name="publication_status" id="publication_status" class="form-control form--control w-100 minimal select2" data-minimum-results-for-search="-1">
                                        <option value="1">@lang('Published')</option>
                                        <option value="0">@lang('Unpublished')</option>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn--dark" data-bs-dismiss="modal">@lang('Close')</button>
                        <button type="submit" class="btn customBtn text-white">@lang('Update')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div id="deleteModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Details')</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="{{ route('user.promotion.delete') }}" method="post">
                    @csrf
                    <div class="modal-body">
                        <input type="hidden" name="id">
                        <strong class="text-dark">@lang('Are you sure to delete this item')?</strong>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-dark" data-bs-dismiss="modal">@lang('Close')</button>
                        <button type="submit" class="btn customBtn text-white">@lang('Delete')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('style')
    <style>
        .select2-container {
            width: 100% !important;
        }

        .select2-container--default .select2-selection--single {
            background-color: #f1f5f8;
            border-width: 1px !important;
            border-color: rgba(4, 38, 86, 0.2) !important;
            padding: 14px 16px !important;
        }

        .select2-container--focus .select2-selection.select2-selection--single,
        .select2-container--focus .select2-selection.select2-selection--multiple {
            outline: none !important;
            box-shadow: none !important;
            background-color: transparent;
            border-color: rgba(30, 144, 255, 0.2) !important;
        }

        .select2-container--open .select2-selection.select2-selection--single,
        .select2-container--open .select2-selection.select2-selection--multiple {
            border-color: rgba(30, 144, 255, 0.2) !important;
        }

        .select2-container--default .select2-selection--single .select2-selection__arrow {
            top: 16px !important;
        }
    </style>
@endpush

@push('script')
    <script>
        (function($) {

            "use strict";

            $('.editBtn').on('click', function() {
                var modal = $('#editModal');
                modal.find('input[name=url]').val($(this).data('url'));
                modal.find('input[name=title]').val($(this).data('title'));
                modal.find('input[name=duration]').val($(this).data('duration'));
                modal.find('input[name=id]').val($(this).data('id'));
                modal.find('select[name=publication_status]').val($(this).data('publish')).change();
                modal.find('select[name=type]').val($(this).data('type'));
                $(".profilePicPreview").attr("style", "background-image:url(" + $(this).data('image') + ")");
                modal.modal('show');
            });

            $('.deleteBtn').on('click', function() {
                var modal = $('#deleteModal');
                modal.find('input[name=id]').val($(this).data('id'));
                modal.modal('show');
            });

            function proPicURL(input) {
                if (input.files && input.files[0]) {
                    var reader = new FileReader();
                    reader.onload = function(e) {
                        var preview = $(input).parents('.thumb').find('.profilePicPreview');
                        $(preview).css('background-image', 'url(' + e.target.result + ')');
                        $(preview).addClass('has-image');
                        $(preview).hide();
                        $(preview).fadeIn(650);
                    }
                    reader.readAsDataURL(input.files[0]);
                }
            }

            $(".profilePicUpload").on('change', function() {
                proPicURL(this);
            });

            $(".remove-image").on('click', function() {
                $(this).parents(".profilePicPreview").css('background-image', 'none');
                $(this).parents(".profilePicPreview").removeClass('has-image');
                $(this).parents(".thumb").find('input[type=file]').val('');
            });

            $("form").on("change", ".file-upload-field", function() {
                $(this).parent(".file-upload-wrapper").attr("data-text", $(this).val().replace(/.*(\/|\\)/, ''));
            });
        })(jQuery);
    </script>
@endpush

@push('style')
    <link rel="stylesheet" href="{{ asset($activeTemplateTrue . '/css/promotion.css') }}">
@endpush
